/*
 * *********************************************************************************************************************
 *
 *          !!
 *        .F88X
 *        X8888Y
 *      .}888888N;
 *        i888888N;        .:!              .I$WI:
 *          R888888I      .'N88~            i8}+8Y&8"l8i$8>8W~'>W8}8]KW+8IIN"8&
 *          .R888888I    .;N8888~          .X8'  "8I.!,/8"  !%NY8`"8I8~~8>,88I
 *            +888888N;  .8888888Y                                  "&&8Y.}8,
 *            ./888888N;  .R888888Y        .'}~    .>}'.`+>  i}!    "i'  +/'  .'i~  !11,.:">,  .~]!  .i}i
 *              ~888888%:  .I888888l      .]88~`1/iY88Ii+1'.R$8$8]"888888888>  Y8$  W8E  X8E  W8888'188Il}Y88$*
 *              18888888    E8888881    .]W%8$`R8X'&8%++N8i,8N%N8+l8%`  .}8N:.R$RE%N88N%N$K$R  188,FE$8%~Y88I
 *            .E888888I  .i8888888'      .:$8I;88+`E8R:/8N,.>881.`$8E/1/]N8X.Y8N`"KF&&FK!'88*."88K./$88%RN888+~
 *            8888888I  .,N888888~        ~88i"8W,!N8*.I88.}888%F,i$88"F88"  888:E8X.>88!i88>`888*.}Fl1]*}1YKi'
 *          i888888N'      I888Y          ]88;/EX*IFKFK88X  K8R  .l8W  88Y  ~88}'88E&%8W.X8N``]88!.$8K  .:W8I
 *        .i888888N;        I8Y          .&8$  .X88!  i881.:%888>I88  ;88]  +88+.';;;;:.Y88X  18N.,88l  .+88/
 *      .:R888888I
 *      .&888888I                                          Copyright (c) 2016-2020.  博锐尚格科技股份有限公司
 *        ~8888'
 *        .!88~                                                                     All rights reserved.
 *
 * *********************************************************************************************************************
 */

import { SGraphEdit, SBaseCirclePolylineEdit } from "@persagy-web/edit";
import { SGraphItem } from "@persagy-web/graph/lib";
import { SMouseEvent } from "@persagy-web/base/lib";
import { Marker } from "@persagy-web/big/lib";
import { SColor, SFont, SPoint, SRect, SSize } from "@persagy-web/draw/lib";

/**
 * 编辑基础管道接头类
 *
 * @author 韩耀龙 <han_yao_long@163.com>
 */
export class SBasePipeUninTool extends SGraphEdit {

    ///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
    //属性
    // 数据
    data: Marker;
    // 宽高
    width: number = 64;
    height: number = 64;
    /** 轮廓 */
    outLine: SBaseCirclePolylineEdit;
    // 轮廓点
    outLineTpye: any = {
        'wantou': 2,
        'santong': 3,
        'sitong': 4,
    }
    /** 轮廓点 */
    outLineLine: SPoint[] = []

    /**
     * 构造函数
     *
     * @param parent    指向父对象
     * @param data      数据
     */
    constructor(parent: SGraphItem | null, data: Marker) {
        super(parent);
        this.data = data;
        this.outLine = new SBaseCirclePolylineEdit(this)
        this.initData(data);
    } // Constructor

    /**
     * 初始化数据
     *
     * @param data Mark
     */
    initData(data: Marker) {
        this.width = data.style.default.width ? data.style.default.width : 64;
        this.height = data.style.default.height ? data.style.default.height : 64;
        this.moveTo(data.pos.x, data.pos.y);
        this.outLine.strokeColor = SColor.Red;
        this.outLine.fillColor = SColor.Red;
        this.outLine.lineWidth = 20;
        // 判断为几通管道
        this.computeUninNumber(this.outLineTpye[data.style.uninToolType]);
        this.outLine.pointList = this.outLineLine; //赋值轮廓
        this.update()
    }

    /**
     * 鼠标按下事件
     *
     * @param event   保存事件参数
     * @return 是否处理该事件
     */
    onMouseDown(event: SMouseEvent): boolean {
        super.onMouseDown(event);
        return true;
    }
    /**
     * 实时变化宽高
     *
     * @param oldSize 旧大小
     * @param newSize 新大小
     */
    resize(oldSize:SSize, newSize:SSize) {
        this.width = newSize.width;
        this.height = newSize.height;
        this.computeUninNumber(this.outLineTpye[this.data.style.uninToolType]);
        this.outLine.pointList = this.outLineLine; //赋值轮廓
        console.log('this.outLineLine',this.outLineLine)
        this.update();
    }

    /**
     * Item 对象边界区域
     *
     * @return 对象边界区域
     */
    boundingRect(): SRect {
        return new SRect(0,0, this.width, this.height);
    }

    /**
     * 计算对应点位
     * @param type 接口数量
     */
    computeUninNumber(type: number) {
        //  如果为二通
        const topPoint = new SPoint(this.width / 2, 0);
        const centerPoint = this.boundingRect().center();
        const rightPoint = new SPoint( this.width, this.height / 2);
        const leftPoint = new SPoint(0,  this.height / 2);
        const bottomPoint = new SPoint(this.width / 2,this.height)
        if (2 == type) {
            this.outLineLine = [topPoint, centerPoint, rightPoint];
        } else if (3 == type) {
            this.outLineLine = [topPoint, centerPoint, rightPoint, leftPoint];
        } else if (4 == type) {
            this.outLineLine = [topPoint, centerPoint, rightPoint, leftPoint, centerPoint, bottomPoint];
        }
    }


    /**
     * 返回对象储存的相关数据
     *
     * @return 相关数据
     */
    toData(): any {
        return super.toData()
    }
}